aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/includes/style/path_provider_interface.php
diff options
context:
space:
mode:
authorVjacheslav Trushkin <arty@phpbb.com>2012-03-15 21:04:27 +0200
committerVjacheslav Trushkin <arty@phpbb.com>2012-03-15 21:04:27 +0200
commitc692e0d92da55944414d5f50accefdd96c2e31ee (patch)
treeaf0829171e76aadd7ea854c0955dfefb47d0a6d8 /phpBB/includes/style/path_provider_interface.php
parent8b7c2c3c6516fd4eb606054ca3822d8a7f977282 (diff)
downloadforums-c692e0d92da55944414d5f50accefdd96c2e31ee.tar
forums-c692e0d92da55944414d5f50accefdd96c2e31ee.tar.gz
forums-c692e0d92da55944414d5f50accefdd96c2e31ee.tar.bz2
forums-c692e0d92da55944414d5f50accefdd96c2e31ee.tar.xz
forums-c692e0d92da55944414d5f50accefdd96c2e31ee.zip
[feature/merging-style-components] Changing path provider
Changing set_templates() to set_style() and removing second parameter, changing get_main_template_path() to get_main_style_path(), removing template_root_for_style(), updating docblocks PHPBB3-10632
Diffstat (limited to 'phpBB/includes/style/path_provider_interface.php')
-rw-r--r--phpBB/includes/style/path_provider_interface.php23
1 files changed, 9 insertions, 14 deletions
diff --git a/phpBB/includes/style/path_provider_interface.php b/phpBB/includes/style/path_provider_interface.php
index e65c037dcc..7ae94e17f4 100644
--- a/phpBB/includes/style/path_provider_interface.php
+++ b/phpBB/includes/style/path_provider_interface.php
@@ -16,16 +16,16 @@ if (!defined('IN_PHPBB'))
}
/**
-* Provides a template locator with paths
+* Provides a style resource locator with paths
*
-* Finds installed template paths and makes them available to the locator.
+* Finds installed style paths and makes them available to the resource locator.
*
* @package phpBB3
*/
interface phpbb_style_path_provider_interface extends Traversable
{
/**
- * Defines a prefix to use for template paths in extensions
+ * Defines a prefix to use for style paths in extensions
*
* @param string $ext_dir_prefix The prefix including trailing slash
* @return null
@@ -33,22 +33,17 @@ interface phpbb_style_path_provider_interface extends Traversable
public function set_ext_dir_prefix($ext_dir_prefix);
/**
- * Overwrites the current template names and paths
+ * Overwrites the current style paths
*
- * @param array $templates An associative map from template names to paths.
- * The first element is the main template.
- * If the path is false, it will be generated from
- * the supplied name.
- * @param string $style_root_path The root directory for styles identified
- * by name only.
+ * @param array $styles An array of style paths. The first element is the main style.
* @return null
*/
- public function set_templates(array $templates, $style_root_path);
+ public function set_styles(array $styles);
/**
* Retrieves the path to the main template passed into set_templates()
*
- * @return string Main template path
+ * @return string Main style path
*/
- public function get_main_template_path();
+ public function get_main_style_path();
}
@@ -33,22 +33,17 @@ interface phpbb_style_path_provider_interface extends Traversable
/**
- * Retrieves the path to the main template passed into set_templates()
+ * Retrieves the path to the main style passed into set_styles()
*